﻿// // -----------------------------------------------------------------------

using System;
using System.Data.Entity;
using System.Data.Entity.Infrastructure;
using System.Linq;
using System.Xml;
using MySql.Data.Entity;
using Xunit;

namespace MySqlConnNetBugs
{

	/// <summary>
	/// Provides a test to show how DateTimeOffset is broken in MySQL Connector.NET v6.8.3.2
	/// </summary>
	public sealed class DateTimeOffsetTests
	{
		/// <summary>
		/// Exercises some of the code called when migrations are run, to show where the breaking point is.
		/// </summary>
		/// <remarks>
		/// To run migrations from package manager console in visual studio:
		///   PM> enable-migrations -EnableAutomaticMigrations -Verbose
		///   PM> update-database -Script -Verbose
		/// </remarks>
		[Fact]
		public void TestGenerateSchema()
		{

			// When migrations are run, an EDMX model is generated.  This does the same, showing where the break is:
			using (var xmlWriter = new XmlTextWriter(Console.Out))
			{
				EdmxWriter.WriteEdmx(new MyDb(), xmlWriter);
			}

		}

		[Fact]
		public void ConnectionOpens()
		{
			bool anyRowsPresent;
			using (var db = new MyDb())
			{
				anyRowsPresent = db.MyEntities.Any();
			}
		}

	}

	public class MyEntity
	{
		public int Id
		{
			get;
			set;
		}
		public DateTimeOffset DateTimeOffset
		{
			get;
			set;
		}
	}

	[DbConfigurationType(typeof(MySqlEFConfiguration))]
	public class MyDb : DbContext
	{
		public DbSet<MyEntity> MyEntities
		{
			get;
			set;
		}
	}

}